import requests
import json
import sys


class APICall:
    def __init__(self, central, token, url, apiPath, group_name, reqtype, payload = None):
        self.central = central
        self.token = token
        self.url = url
        self.apiPath = apiPath,
        self.group_name = group_name,
        self.reqtype = reqtype
        self.payload = payload

    def getData(self):

        while True:
            headers = {
                "Content-Type": "application/json",
                "Authorization": "Bearer " + self.token['access_token'],
            }
            params = {"group_name": self.group_name[0]}

            if self.payload is None:
                payload = {}
            else:
                payload = self.payload

            if self.reqtype == "get":
                response = requests.get(
                    self.url
                    # + self.apiPath[0] + "?group_name=" + self.group_name[0],
                    + self.apiPath[0],
                    headers=headers,
                    params=params,
                    data=json.dumps(payload)
                )
            elif self.reqtype == "post":
                response = requests.post(
                    self.url
                    # + self.apiPath[0] + "?group_name=" + self.group_name[0],
                    + self.apiPath[0],
                    headers=headers,
                    params=params,
                    data=json.dumps(payload)
                )
            else:
                print("ERROR: No request type sent.")
                sys.exit(1)
            try:
                response.raise_for_status()
            except requests.exceptions.HTTPError as err:
                if response.status_code == 401:
                    print(f"Refreshing Aruba Central Token...")
                    newtoken = self.central.refreshToken(self.token)
                    if "access_token" in newtoken:
                        self.central.storeToken(newtoken)
                        self.central.central_info["token"] = newtoken
                        self.token = newtoken
                else:
                    print(f"Error: {err}")
                    break
                continue
            break
        return response.json()



#!/usr/bin/env python3 

import requests
import logging
import json, pickle
from selenium import webdriver
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.common.exceptions import TimeoutException
from selenium.webdriver.common.by import By

import central_config as cfg

logging.basicConfig(level=logging.DEBUG)

#
# Edit the config.py
#
#
# This script uses Selenium to login to Aruba Central to grab the cookie that is needed for the CaaS API
# Please set your username and password here.
# If your central instances is configured for SSO, it is recommended you create a local account
#

# Set webdriver for Selenium
if cfg.webbrowser == "Firefox":
    driver = webdriver.Firefox()
elif cfg.webbrowser == "Chrome":
    driver = webdriver.Chrome()

# Connect to the URL and get data
driver.get(cfg.url)

# Login
driver.find_element_by_id("email").send_keys(cfg.username)
driver.find_element_by_id("signIn_button").click()
driver.find_element_by_id("password").send_keys(cfg.password)
driver.find_element_by_id("signIn_button").click()


#
# Begin - Customer Selector
#
wait = WebDriverWait(driver, 10)
timeout = 5  # seconds
try:
    element_present = EC.presence_of_element_located((By.ID, cfg.account_selection))
    WebDriverWait(driver, timeout).until(element_present)
except TimeoutException:
    print("Timed out waiting for page to load")
# wait.until(EC.title_is('Select Account'))
driver.find_element_by_id(cfg.account_selection).click()
#
# End - Customer Selector
#


#
# Code to select the Netowrk Operations page from the Account Home.
# This may not be necessary as there's a cookie set, but unknown if Netowrk Operations generates
# a new cookie or not
#
try:
    element_present = EC.presence_of_element_located(
        (By.CSS_SELECTOR, ".app-details-container-big:nth-child(1) .app-details-button")
    )
    WebDriverWait(driver, timeout).until(element_present)
except TimeoutException:
    print("Timed out waiting for page to load")
driver.find_element_by_css_selector(
    ".app-details-container-big:nth-child(1) .app-details-button"
).click()

# Get cookies and save them to a file
pickle.dump(driver.get_cookies(), open(cfg.cookie_file, "wb"))

print("If there werent any issues, then you can now run caas.py. Please note that the Aruba Central cookies expire after 15min if idle")


import sys
from pathlib import Path

from loguru import logger

WORK_DIR = Path(__file__).parents[2]
sys.path.append(str(WORK_DIR / "arubacentralcaas/arubacentralcaas"))
sys.path.append(str(WORK_DIR / "arubacentralcaas"))

from .config.settings import log_level  # noqa: E402

logger.remove()


class LogFilter:
    def __init__(self, level):
        self.level = level

    def __call__(self, record):
        levelno = logger.level(self.level).no
        return record["level"].no >= levelno


log_filter = LogFilter(log_level)  # type: ignore

logger.add(
    sys.stderr,
    colorize=True,
    filter=log_filter,
    format="<green>{time:YYYY-MM-DD HH:mm:ss}</green> | <blue>{level}</blue> |"
    " <cyan>{name}:{function}:{line}</cyan> | <bold><level>{message}</level></bold>",
    level=0,
)



#!/usr/bin/env python3

import requests, json, logging, sys
import yaml
import os
from pprint import pprint
from pycentral.base import ArubaCentralBase
from lib import getapi


logging.basicConfig(
    format="%(asctime)s - %(name)s — %(levelname)s - %(message)s", level=logging.WARNING
)
logging.getLogger("ARUBA_BASE").setLevel(logging.WARNING)
logger = logging.getLogger(__name__)


def main():
    if "CENTRAL_ACCOUNT" in os.environ:
        account = os.environ["CENTRAL_ACCOUNT"]
    else:
        logger.error(
            "CENTRAL_ACCOUNT environment variables is not set. Please set with the account profile used in the config (config.yaml) file. Please see README.md file."
        )
        sys.exit(1)

    if "CENTRAL_REGION" in os.environ:
        region = os.environ["CENTRAL_REGION"]
    else:
        logger.error(
            "CENTRAL_REGION environment variables is not set. Please set with the account profile used in the config (config.yaml) file. Please see README.md file."
        )
        sys.exit(1)

    logger.info(f"ACCOUNT: {account} REGION:{region}")

    # group_name = "greendots/20:4c:03:12:33:20"
    if len(sys.argv) > 1:
        group_name = sys.argv[1]
    else:
        print("Group name is not set. \n show_committed.py GROUP_NAME|GROUP_NAME/MAC.\nSee README.md")
        sys.exit(1)

    # Open file and grab the token
    with open(r"config/config.yaml") as file:
        configfile = yaml.load(file, Loader=yaml.FullLoader)

    central_info = configfile[account]
    region_url = configfile["regions"][region]

    central = ArubaCentralBase(central_info=central_info, ssl_verify=True)

    logger.debug(f"token {central.getToken()['access_token']}:")

    # config_path for AOS10, group_name for all others. May be interchangable.
    # params = {"config_path": "/md/XXV-SEATTLE"}
    # params = {"group_name": group_name }


    token = central.loadToken()
    apiPath = "/caasapi/v1/showcommand/object/committed"

    response = getapi.APICall(central = central, token = token, url = region_url, apiPath = apiPath, reqtype="get", group_name = group_name)
    pprint(response.getData(), indent=2)


if __name__ == "__main__":
   main()



import pathlib
import sys

import pytest

cwd = pathlib.Path.cwd()

# Add the project's root directory to the system path
sys.path.append(str(cwd.parent))

# This is optional, but you can add a lib directory
# To the system path for tests to be able to use
sys.path.append(str(cwd / "lib"))

pytest.main()



#!/usr/bin/env python3

import requests, json, logging, sys
import yaml
import os
from pprint import pprint
from pycentral.base import ArubaCentralBase
from lib import getapi


def main():
    logging.basicConfig(
        format="%(asctime)s - %(name)s — %(levelname)s - %(message)s",
        level=logging.WARNING,
    )
    logging.getLogger("ARUBA_BASE").setLevel(logging.WARNING)
    logger = logging.getLogger(__name__)

    if "CENTRAL_ACCOUNT" in os.environ:
        account = os.environ["CENTRAL_ACCOUNT"]
    else:
        logger.error(
            "CENTRAL_ACCOUNT environment variables is not set. Please set with the account profile used in the config (config.yaml) file. Please see README.md file."
        )
        sys.exit(1)

    if "CENTRAL_REGION" in os.environ:
        region = os.environ["CENTRAL_REGION"]
    else:
        logger.error(
            "CENTRAL_REGION environment variables is not set. Please set with the account profile used in the config (config.yaml) file. Please see README.md file."
        )
        sys.exit(1)

    logger.info(f"ACCOUNT: {account} REGION:{region}")

    # group_name = "greendots/20:4c:03:12:33:20"
    group_name = sys.argv[2]

    with open(sys.argv[1], "rb") as pf:
        payload = json.load(pf)

    # Open file and grab the token
    with open(r"config/config.yaml") as file:
        configfile = yaml.load(file, Loader=yaml.FullLoader)

    central_info = configfile[account]
    region_url = configfile["regions"][region]

    central = ArubaCentralBase(central_info=central_info, ssl_verify=True)
    logger.debug(f"token {central.getToken()['access_token']}:")

    # CLI command to send
    # payload = (
    #     '{"cli_cmds": ["vlan 879", "description \'This is API description\'", "!"]}'
    # )

    # Another example of a CLI command - multi-line
    # payload =  {
    #     "cli_cmds": [
    #         "netdestination test-api-alias",
    #         "host 1.2.3.4",
    #         "!",
    #         "ip access-list session test-api-acl",
    #         "alias test-api-alias any any permit",
    #         "!"
    #         ]
    # }

    # config_path for AOS10, group_name for all others. May be interchangable.
    # params = {"config_path": "/md/XXV-SEATTLE"}

    token = central.loadToken()
    apiPath = "/caasapi/v1/exec/cmd"


    response = getapi.APICall(central = central, token = token, url = region_url, apiPath = apiPath, reqtype="post", group_name = group_name, payload = payload)
    # pprint(response.getData(), indent=2)
    print(response.getData()['_global_result']['status_str'])




if __name__ == "__main__":
    main()



import json

# sys.path.append("..")
# from arubacentralcaas.config import settings  # noqa: E402

# import sys


class central_test:
    def __init__(self, function_called):
        self.function_called = function_called

    def command(self, **kwargs):
        test_file_name = f"test_{self.function_called[0]}.json"
        test_dir = self.function_called[1]
        print(f"\nUsing test file: [yellow]{test_file_name}[/yellow]")
        with open(f"{test_dir}{test_file_name}", "r") as file:
            test_json = json.load(file)
        return test_json



import sys
from pathlib import Path

sys.path.append(str(Path(".").absolute().parent))
from app import app  # noqa: E402
from typer.testing import CliRunner  # noqa: E402

runner = CliRunner()


def test_show_accounts():
    result = runner.invoke(app, ["show-accounts"])
    assert result.exit_code == 0
    assert "central_info" in result.stdout


def test_show_gateways():
    result = runner.invoke(app, ["show-gateways", "--account", "tests"])
    assert result.exit_code == 0
    assert "Gateways" in result.stdout


# def test_show_routes():
#     result = runner.invoke(
#         app, ["show-routes", "aws-usw2-aruba-poc", "--account", "tests"]
#     )
#     assert result.exit_code == 0
#     assert "config" in result.stdout


def test_show_committed():
    result = runner.invoke(app, ["show-committed", "DDDD", "--account", "tests"])
    assert result.exit_code == 0
    assert "mcs" in result.stdout


def test_show_effective():
    result = runner.invoke(
        app, ["show-committed", "aws-usw2-aruba-poc", "--account", "tests"]
    )
    assert result.exit_code == 0
    assert "mcs" in result.stdout



import sys
from pathlib import Path

sys.path.append(str(Path(".").absolute().parent))
from ..config.settings import get_config, get_ttl_hash  # noqa: E402
from ..views.displays import check_output  # noqa: E402


def show_device_committed(group_name, account):
    central = get_config(account, ttl_hash=get_ttl_hash())
    apiPath = "/caasapi/v1/showcommand/object/committed"
    apiMethod = "GET"
    apiParams = {"limit": 0, "offset": 0, "group_name": group_name}
    query = central.command(apiMethod=apiMethod, apiPath=apiPath, apiParams=apiParams)
    return query


def show_device_effective(group_name, account):
    central = get_config(account, ttl_hash=get_ttl_hash())
    apiPath = "/caasapi/v1/showcommand/object/effective"
    apiMethod = "GET"
    apiParams = {"limit": 0, "offset": 0, "group_name": group_name}
    query = central.command(apiMethod=apiMethod, apiPath=apiPath, apiParams=apiParams)

    return query


def get_gateways(account):
    central = get_config(account, ttl_hash=get_ttl_hash())
    apiPath = "/monitoring/v1/mobility_controllers"
    apiMethod = "GET"
    apiParams = {"sku_type": "GATEWAY"}
    query = central.command(apiMethod=apiMethod, apiPath=apiPath, apiParams=apiParams)
    response = check_output(query)
    return response


def get_routes(serial, account):
    central = get_config(account, ttl_hash=get_ttl_hash())
    apiPath = "/api/routing/v1/route"
    apiMethod = "GET"
    apiParams = {"device": serial}
    query = central.command(apiMethod=apiMethod, apiPath=apiPath, apiParams=apiParams)
    response = check_output(query)
    return response



#!/usr/bin/env python3

import requests, json, pickle, logging, sys
from pprint import pprint
import central_config as cfg

# Enable logging. If its too verbose, change DEBUG to ERROR or another level
logging.basicConfig(level=logging.DEBUG)

# group_name = "greendots/20:4c:03:12:33:20"
group_name = sys.argv[2]

with open(sys.argv[1], "rb") as pf:
    payload = json.load(pf)



# CLI command to send
# payload = (
#     '{"cli_cmds": ["vlan 879", "description \'This is API description\'", "!"]}'
# )

# Another example of a CLI command - multi-line
# payload =  {
#     "cli_cmds": [
#         "netdestination test-api-alias",
#         "host 1.2.3.4",
#         "!",
#         "ip access-list session test-api-acl",
#         "alias test-api-alias any any permit",
#         "!"
#         ]
# }

# Open file and grab the cookie Selenium created
with open(cfg.cookie_file, "rb") as f:
    cookies_data = pickle.load(f)

logging.debug("COOKIE %s:", cookies_data)

# Convert the cookie into a format Python requests can use.
c = {c["name"]: c["value"] for c in cookies_data}

# config_path for AOS10, group_name for all others. May be interchangable.
# params = {"config_path": "/md/XXV-SEATTLE"}
params = {"cid": cfg.customer_id, "group_name": group_name}

headers = {
    "Content-Type": "application/json",
}
response = requests.post(cfg.network_url + "/caas/v1/exec/cmd", params=params, headers=headers, data=json.dumps(payload), cookies=c)

print("POST Status Code: ", response.status_code)
print("POST Response: ")
pprint(response.json())

# commited = requests.get(cfg.network_url + "/caas/v1/showcommand/object/committed?group_name=" + group_name, headers=headers, cookies=c)
# print("Commit Status Code: ", commited.status_code)
# pprint(commited.json())








import inspect
import ipaddress
import json

from rich import box, print
from rich.console import Console
from rich.table import Table

from ..config.settings import configfile  # noqa: E402
from ..config.settings import save_output_dir, settings

console = Console()


def display_output(output, save=None):
    if output["code"] != 200:
        print(f"\n\n[red]Error Status Code: {output['code']} : {output['msg']}[/red]")
        exit(1)
    else:
        command_called = inspect.stack()[2][3]
        if save:
            with open(f"{save_output_dir}/{command_called}.json", "w+") as file:
                json.dump(output["msg"], file, indent=4)
        from rich import print_json

        print_json(json.dumps(output["msg"]))


def check_output(output):
    # Dump output for building tests
    # with open("temp/output.json", "w+") as file:
    #     json.dump(output, file, indent=4)
    if output["code"] != 200:
        print(f"\n\n[red]Error Status Code: {output['code']} : {output['msg']}[/red]")
        exit(1)
    else:
        return output["msg"]


def display_account(account):
    print(f"Account Name: [#ff8300]{settings.ACCOUNT}[/#ff8300]")
    print("\nOther accounts in config file:")
    for profiles in configfile.keys():
        print(f"\t[cyan]{profiles}[/cyan]")


def display_gateways(gateways):
    gateway_table = Table(title="Gateways", box=box.SIMPLE)
    gateway_table.add_column("Name")
    gateway_table.add_column("SN")
    gateway_table.add_column("IP")
    gateway_table.add_column("MAC")
    gateway_table.add_column("Group")
    gateway_table.add_column("Status")
    gateway_table.add_column("GROUP/MAC")

    for eachgw in gateways["mcs"]:
        gateway_table.add_row(
            eachgw["name"],
            eachgw["serial"],
            eachgw["ip_address"],
            eachgw["macaddr"],
            eachgw["group_name"],
            eachgw["status"],
            f'[bold cyan]{eachgw["group_name"]}/{eachgw["macaddr"]}[/bold cyan]',
        )

    console.print(gateway_table)


def display_routes(serial, routes):
    # print(routes["summary"])
    # print(routes["routes"])
    print("")
    route_summary = Table(title="Route Summary", show_header=False, box=box.SIMPLE)
    route_summary.add_row("Total Routes", str(routes["summary"]["total"]))
    route_summary.add_row("Default Routes", str(routes["summary"]["default"]))
    route_summary.add_row("Static Routes", str(routes["summary"]["static"]))
    route_summary.add_row("Connected Routes", str(routes["summary"]["connected"]))
    route_summary.add_row("Overlay Routes", str(routes["summary"]["overlay"]))

    console.print(route_summary)

    route_table = Table(title=f"Route Table: {serial}", box=box.SIMPLE)
    route_table.add_column(
        "",
    )
    route_table.add_column("Destination")
    route_table.add_column("D/M")
    route_table.add_column("Nexthop")
    for route in routes["routes"]:
        if route["nexthop"][0]["protocol"] != "Connected":
            if route["nexthop"][0]["protocol"] == "Static":
                rowstyle = "cyan"
            else:
                rowstyle = "#d78700"
            try:
                nexthopip = ipaddress.ip_address(route["nexthop"][0]["address"])
                route_table.add_row(
                    route["nexthop"][0]["protocol"],
                    route["prefix"] + "/" + str(route["length"]),
                    "[" + str(route["nexthop"][0]["admin_distance"]) + "/" + str(route["nexthop"][0]["metric"]) + "]",
                    "via " + route["nexthop"][0]["address"],
                    style=rowstyle,
                )
            except ValueError:
                # nexthopip = route["nexthop"][0]["address"]
                nexthopip = 0
            if nexthopip == 0:
                if len(route["nexthop"]) > 1:
                    nexthopaddress = ""
                    for nh in route["nexthop"]:
                        nexthopaddress += "ipsec map " + nh["address"] + "\n"
                else:
                    nexthopaddress = "ipsec map " + route["nexthop"][0]["address"]
                route_table.add_row(
                    route["nexthop"][0]["protocol"],
                    route["prefix"] + "/" + str(route["length"]),
                    "[" + str(route["nexthop"][0]["admin_distance"]) + "/" + str(route["nexthop"][0]["metric"]) + "]",
                    nexthopaddress,
                    style=rowstyle,
                )
    console.print(route_table)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['arubacentralcaas',
 'arubacentralcaas.config',
 'arubacentralcaas.deprecated',
 'arubacentralcaas.deprecated.cookie_version',
 'arubacentralcaas.deprecated.lib',
 'arubacentralcaas.model',
 'arubacentralcaas.tests',
 'arubacentralcaas.views']

package_data = \
{'': ['*'],
 'arubacentralcaas': ['.cache/*', 'images/*', 'samples/*'],
 'arubacentralcaas.tests': ['resources/*']}

install_requires = \
['ipaddress>=1.0.23,<2.0.0',
 'loguru>=0.6.0,<0.7.0',
 'pycentral>=0.0.3,<0.0.4',
 'pydantic>=1.9.0,<2.0.0',
 'rich>=12.3.0,<13.0.0',
 'typer>=0.4.1,<0.5.0']

entry_points = \
{'console_scripts': ['caas = arubacentralcaas.app:app']}

setup_kwargs = {
    'name': 'arubacentralcaas',
    'version': '0.1.5',
    'description': 'Aruba Central CaaS API CLI',
    'long_description': None,
    'author': 'Michael Rose Jr.',
    'author_email': 'michael@michaelrosejr.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from typing import Optional

import typer
from rich import print
from rich.console import Console

from .config.settings import settings
from .model.push_config import caas_push_config
from .model.shows import get_gateways, get_routes, show_device_committed, show_device_effective
from .views.displays import display_account, display_gateways, display_output, display_routes

console = Console()
app = typer.Typer()


storedaccount = settings.ACCOUNT
print(
    f"\nUsing acccount: [#ff8300]{storedaccount}[/#ff8300]. \nTo change use --account or"
    " set the ACCOUNT environment variable: [yellow]export ACCOUNT='myprofile'[/yellow].\n"
)


@app.command()
def show_accounts(account: str = typer.Option(storedaccount, help="show accounts")):
    """
    show a list of accounts configured in the config.yaml file

    """
    display_account(account)


@app.command()
def show_routes(
    serial: str = typer.Argument(..., help="show route table for device"),
    account: str = typer.Option(storedaccount, help="show gateways"),
):
    """
    show route table for device

    SERIAL required for this command
    """
    with console.status("Getting Routes...", spinner="point", spinner_style="bold green"):
        routes = get_routes(serial, account)
    display_routes(serial, routes)


@app.command()
def show_gateways(account: str = typer.Option(storedaccount, help="show gateways")):
    """
    show list of gateways in Central account

    """
    with console.status("Getting gateways...", spinner="point", spinner_style="bold green"):
        gateways = get_gateways(account)
    display_gateways(gateways)


@app.command()
def show_committed(
    group: str = typer.Argument(
        ...,
        help="show configuration committed for group or group/mac_addr. Ex: Seattle or Seattle/c2:46:65:dc:f8:16",
    ),
    account: str = typer.Option(storedaccount, help="show gateways"),
    save: Optional[bool] = False,
):
    """
    'show configuration committed' for group/device
    """
    with console.status("Getting show committed...", spinner="point", spinner_style="bold green"):
        query = show_device_committed(group, account)
        display_output(query, save)


@app.command()
def show_effective(
    group: str = typer.Argument(
        ...,
        help="show configuration effective for group or group/mac_addr. Ex: Seattle or Seattle/c2:46:65:dc:f8:16",
    ),
    account: str = typer.Option(storedaccount, help="show gateways"),
    save: Optional[bool] = False,
):
    """
    'show configuration effective' for group/device
    """
    with console.status("Getting show effective...", spinner="point", spinner_style="bold green"):
        query = show_device_effective(group, account)
        display_output(query, save)


@app.command()
def push_config(
    config_file: str = typer.Argument(..., help="json config file to push"),
    groupdev_name: str = typer.Argument(
        ...,
        help="group/device name of group/device. Ex: Seattle or Seattle/c2:46:65:dc:f8:16",
    ),
    account: str = typer.Option(storedaccount, help="show gateways"),
):
    """

    Push json config to group/device.

    Ex: ./caas push-config newroute.json Seattle/c2:46:65:dc:f8:16

    """

    query = caas_push_config(config_file, groupdev_name, account)
    print(query)


if __name__ == "__main__":
    app()



import inspect
import sys
import time
from functools import lru_cache
from pathlib import Path

import yaml
from loguru import logger
from pycentral.base import ArubaCentralBase
from pydantic import BaseSettings

from ..model.tests import central_test

test_dir = "tests/resources/"
save_output_dir = "temp/"
log_level = "INFO"

logger.add(sys.stderr, format="{time} {level} {message}", filter="my_module", level="INFO")


class Settings(BaseSettings):
    ACCOUNT: str = "central_info"


settings = Settings()  # type: ignore

# Look for config.yaml file
config_file_name = "config.yaml"
local_dir = f"{Path.home()}/{config_file_name}"
local_dir_config = f"{Path.home()}/.config/central/{config_file_name}"
if Path(local_dir).exists():
    config_file = local_dir
elif Path(local_dir_config).exists():
    config_file = local_dir_config
else:
    print(f"\n[red]Config file not found: {local_dir_config}[/red]")
    exit(1)
with open(config_file, "r") as file:
    configfile = yaml.load(file, Loader=yaml.FullLoader)


@lru_cache
def get_config(account, ttl_hash=None):
    del ttl_hash  # to emphasize we don't use it and to shut pylint up
    global storedaccount
    storedaccount = account
    # One day we will use this to cache the config
    # account_name = {
    #     "storedaccount": storedaccount,
    # }
    # cachefile = ".cache/caascache.json"
    # Path(".cache").mkdir(parents=True, exist_ok=True)
    # cachefile = Path(cachefile)
    # if cachefile.is_file():
    #     with open(cachefile, "r") as file:
    #         token = file.read()
    # else:
    #     cachefile.touch(exist_ok=True)
    #     with open(cachefile, "w+") as cache:
    #         json.dump(account_name, cache)
    central_info = configfile[storedaccount]
    # Grab the calling function so we can use it for testing
    calling_function = list()
    calling_function.append(inspect.stack()[1][3])
    calling_function.append(test_dir)

    if account == "tests":
        # Send name of calling function to pull test json file
        central = central_test(calling_function)
    else:
        central = ArubaCentralBase(central_info=central_info, ssl_verify=True, logger=logger)

    return central


def get_ttl_hash(seconds=300):
    """Return the same value withing `seconds` time period"""
    return round(time.time() / seconds)



import json

from rich import print
from rich.console import Console

from ..config.settings import configfile, get_config, get_ttl_hash

console = Console()


def caas_push_config(config_file, groupdev_name, account):
    central = get_config(account, ttl_hash=get_ttl_hash())
    with open(config_file, "rb") as jfile:
        payload = json.load(jfile)
    if "cli_cmds" not in payload.keys():
        print(
            "[red]\nError: The config file does not contain any CLI commands. \
                Please check the config file to ensure 'cli_cmds' is present."
        )
        exit(1)
    else:
        apiPath = "/caasapi/v1/exec/cmd"
        apiMethod = "POST"
        apiParams = {
            "cid": configfile[account]["customer_id"],
            "group_name": groupdev_name,
        }
        apiHeaders = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {central.getToken()['access_token']}",  # type: ignore
        }
        print(f"[bold]You are about to push changes to the account[/bold] [#ff8300]{account}[/#ff8300]!")
        confirm = console.input(
            f"Type`[bold red]confirm[/bold red]` to [red]push[/red] changes in file \
                '[cyan]{config_file}[/cyan]' to [yellow]{groupdev_name}[/yellow]: "
        )

        if confirm == "confirm":
            print("\nConfirmation recieved!")
            print(f"Pushing configuration in [blue]{config_file}[/blue] to [green]{groupdev_name}[/green]...\n")
            query = central.command(
                apiMethod=apiMethod,
                headers=apiHeaders,
                apiPath=apiPath,
                apiParams=apiParams,
                apiData=payload,
            )

            if query["code"] != 200:
                response = f"[red]Error Status Code: {query['code']} : {query['msg']}[/red]"
            else:
                response = query["msg"]
        else:
            print("Aborting changes...")
            response = ""
            exit(1)
    return response
